pub struct FileEntry<'data> {
pub info: FileInfo<'data>,
/* private fields */
}Expand description
File information comprising a compilation directory, relative path and name.
Fields
info: FileInfo<'data>File name and path.
Implementations
Sourceimpl<'data> FileEntry<'data>
impl<'data> FileEntry<'data>
Sourcepub fn new(compilation_dir: Cow<'data, [u8]>, info: FileInfo<'data>) -> Self
pub fn new(compilation_dir: Cow<'data, [u8]>, info: FileInfo<'data>) -> Self
Path to the compilation directory.
Sourcepub fn compilation_dir_str(&self) -> Cow<'data, str>
pub fn compilation_dir_str(&self) -> Cow<'data, str>
Path to the compilation directory.
Sourcepub fn abs_path_str(&self) -> String
pub fn abs_path_str(&self) -> String
Absolute path to the file, including the compilation directory.
Sourcepub fn srcsrv_path_str(&self) -> Option<String>
pub fn srcsrv_path_str(&self) -> Option<String>
The full path to the file on the source server.
This only exists if we have a debug file containing source server information.
Methods from Deref<Target = FileInfo<'data>>
Sourcepub fn dir_str(&self) -> Cow<'data, str>
pub fn dir_str(&self) -> Cow<'data, str>
Path to the file relative to the compilation directory.
Sourcepub fn path_str(&self) -> String
pub fn path_str(&self) -> String
The full path to the file, relative to the compilation directory.
Sourcepub fn srcsrv_name_str(&self) -> Option<Cow<'data, str>>
pub fn srcsrv_name_str(&self) -> Option<Cow<'data, str>>
The file name on the source server as UTF-8 string.
This only exists if we have a debug file containing source server information.
Sourcepub fn srcsrv_dir_str(&self) -> Option<Cow<'data, str>>
pub fn srcsrv_dir_str(&self) -> Option<Cow<'data, str>>
Path to the file on the source server.
This only exists if we have a debug file containing source server information.
Sourcepub fn srcsrv_path_str(&self) -> Option<String>
pub fn srcsrv_path_str(&self) -> Option<String>
The full path to the file on the source server.
This only exists if we have a debug file containing source server information.
Sourcepub fn srcsrv_revision(&self) -> Option<&str>
pub fn srcsrv_revision(&self) -> Option<&str>
The optional VCS revision (e.g., Perforce changelist, git commit hash).
This only exists if we have a debug file containing source server information.