Struct symbolic_debuginfo::Object
[−]
[src]
pub struct Object<'bytes> { /* fields omitted */ }Represents a single object in a fat object.
Methods
impl<'bytes> Object<'bytes>[src]
fn id(&self) -> Option<ObjectId>[src]
Returns the identifier of the object.
fn uuid(&self) -> Option<Uuid>[src]
Returns the UUID of the object.
Unless the UUID is specifically required, consider using Object::id instead.
fn kind(&self) -> ObjectKind[src]
Returns the kind of the object.
fn arch(&self) -> Arch[src]
Returns the architecture of the object.
fn vmaddr(&self) -> Result<u64>[src]
Return the vmaddr of the code portion of the image.
fn endianness(&self) -> Endianness[src]
True if little endian, false if not.
fn as_bytes(&self) -> &'bytes [u8][src]
Returns the content of the object as bytes.
fn class(&self) -> ObjectClass[src]
Returns the desiganted use of the object file and hints at its contents.
fn debug_kind(&self) -> Option<DebugKind>[src]
Returns the type of debug data contained in this object file.