ParseObjectOptions

Struct ParseObjectOptions 

#[non_exhaustive]
pub struct ParseObjectOptions { pub max_decompressed_section_size: Option<usize>, pub max_decompressed_embedded_source_size: Option<usize>, }
Options for parsing object files.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_decompressed_section_size: Option<usize>

The maximum uncompressed size for compressed debug file sections.

This is only relevant to ELF objects.

max_decompressed_embedded_source_size: Option<usize>

The maximum uncompressed size for comprossed source files embedded in an object file.

This is only relevant for source bundles and PPDB objects.