pub struct PdbDebugSession<'d> { /* private fields */ }Expand description
Debug session for PDB objects.
Implementations
Sourceimpl<'d> PdbDebugSession<'d>
impl<'d> PdbDebugSession<'d>
Sourcepub fn files(&self) -> PdbFileIterator<'_> ⓘ
pub fn files(&self) -> PdbFileIterator<'_> ⓘ
Returns an iterator over all source files in this debug file.
Sourcepub fn functions(&self) -> PdbFunctionIterator<'_> ⓘ
pub fn functions(&self) -> PdbFunctionIterator<'_> ⓘ
Returns an iterator over all functions in this debug file.
Sourcepub fn source_by_path(
&self,
_path: &str,
) -> Result<Option<SourceFileDescriptor<'_>>, PdbError>
pub fn source_by_path( &self, _path: &str, ) -> Result<Option<SourceFileDescriptor<'_>>, PdbError>
See DebugSession::source_by_path for more information.
Sourcepub fn srcsrv_vcs_name(&self) -> Option<String>
pub fn srcsrv_vcs_name(&self) -> Option<String>
Returns the SRCSRV VCS integration name if available.
This extracts the version control system identifier from the SRCSRV stream,
if present. Common values include “perforce”, “tfs”, “git”, etc.
Returns None if no SRCSRV stream exists or if it cannot be parsed.